==> flutter_alertdialog-0.0.4.tar.gz: lib/flutter_alertdialog.dart <==
library flutter_alertdialog;

import 'package:flutter/material.dart';

class AlertDialog extends StatelessWidget {

  final Color color;
  final Color backgroundColor;

  final Text header;
  final Text message;
  final List<Widget> actions;

  AlertDialog({Key key, this.color, this.backgroundColor, this.header, this.message, this.actions}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: new BoxDecoration(
        borderRadius: new BorderRadius.all(
            new Radius.circular(32)
        ),
        color: Colors.lightBlue,
      ),
      child: new Container(
        width: 300.0,
        color: this.backgroundColor,
        child: new Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            new Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                this.header
              ],
            ),
            new SizedBox(
              height: 5.0,
            ),
            new Divider(
              color: color,
              height: 4.0,
            ),
            new Padding(
              padding: EdgeInsets.symmetric(horizontal: 30.0),
              child: this.message,
            ),
            new InkWell(
              child: new Container(
                padding: EdgeInsets.symmetric(vertical: 20.0),
                decoration: new BoxDecoration(
                  color: Colors.lightBlue,
                  borderRadius: BorderRadius.only(
                    bottomLeft: Radius.circular(32.0),
                    bottomRight: Radius.circular(32.0),
                  ),
                ),
                child: new Column(
                  children: this.actions,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> flutter_alertdialog-0.0.5.tar.gz: lib/flutter_alertdialog.dart <==
library flutter_alertdialog;

import 'package:flutter/material.dart';

class FlutterAlertDialog extends StatelessWidget {

  final Color color;
  final Color backgroundColor;

  final Text header;
  final Text message;
  final List<Widget> actions;

  FlutterAlertDialog({Key key, this.color, this.backgroundColor, this.header, this.message, this.actions}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: new BoxDecoration(
        borderRadius: new BorderRadius.all(
            new Radius.circular(32)
        ),
        color: Colors.lightBlue,
      ),
      child: new Container(
        width: 300.0,
        color: this.backgroundColor,
        child: new Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            new Row(
              mainAxisAlignment: MainAxisAlignment.spaceEvenly,
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                this.header
              ],
            ),
            new SizedBox(
              height: 5.0,
            ),
            new Divider(
              color: color,
              height: 4.0,
            ),
            new Padding(
              padding: EdgeInsets.symmetric(horizontal: 30.0),
              child: this.message,
            ),
            new InkWell(
              child: new Container(
                padding: EdgeInsets.symmetric(vertical: 20.0),
                decoration: new BoxDecoration(
                  color: Colors.lightBlue,
                  borderRadius: BorderRadius.only(
                    bottomLeft: Radius.circular(32.0),
                    bottomRight: Radius.circular(32.0),
                  ),
                ),
                child: new Column(
                  children: this.actions,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
